pkgsrc-Changes archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

CVS commit: pkgsrc/math/octave



Module Name:    pkgsrc
Committed By:   adam
Date:           Sun Apr 12 21:19:33 UTC 2020

Modified Files:
        pkgsrc/math/octave: Makefile PLIST buildlink3.mk distinfo octave.mk
        pkgsrc/math/octave/patches: patch-libinterp_corefcn_input.cc
            patch-m4_acinclude.m4

Log Message:
octave: updated to 5.2.0

Summary of bugs fixed for version 5.2.0:

Improvements

- Lock amd and symbfact to avoid segmentation fault with SuiteSparse
- Fix segfault when calculating patch vertex normals
- Fix segfault in constructing patch normals for lighting
- mat2str.m: Fix for logical matrix (add `transpose`).
- improve file equality check for MS Windows
- ismember.m: Fix second return argument when values are complex
- findobj.m: Fix typo and correctly handle numeric properties
- Correctly display integer types with format hex
- Cast `winqueryreg` `REG_DWORD` types to `DWORD`
- Fix numerous errors in `audiowrite` / `audioread`
- print.m: Pass quoted path to `octave-svgconvert`
- dir.m: Fix occasionally returning incorrect folder field
- Stop segfault when calling 3-input form of `diag` with cell arrays
- improve message for setting breakpoint in nonexistent function
- Use framebuffer object for printing invisible Qt figures on mac
- Escape backslash characters in `EPS` output
- Use replacement characters to display non UTF-8 strings in figures
- inputrc: Add warning about modification
- documentation.cc (global_search): just return if query string is empty
- Default (c)transpose for old style class arrays
- Always reserve at least 1 element of storage for sparse matrices
- Don't segfault at exit after reading malformed HDF5 file
- Fix pause() with no arguments called on Windows
- refactor minimum eigenvalue index search in `qp`
- qp: fix obscure corner case when calculating `qp` caused by a typo
- use `std::streampos` instead of `std::ios::streampos`.
- fix `pause` and `kbhit` with glibc 2.28 end-of-file state behavior
- Fix return of left-handed vectors when inputs are complex
- waitbar.m: Fix hang when using `createcancelbtn` property
- shading.m: Fix unexpected error when multiple `hggroups` present
- dec2base.m: Correctly handle zero matrix input
- eliminate duplicate graphics callback object stack
- Improve performance when closing figures
- Reduce time to process `pkg -forge list` by 30X
- Feed `fig2dev` with PDF files converted from svg
- Improve error checking for `iconv_open`.
- poly.m: fix the fix for input of complex conjugate pairs
- mkoctfile: use the `TMPDIR` environment variable if set
- line.m: Fix creation of unwanted axes
- Accept 4-input form for quiver3
- pkg.m: restore installing packages from zip archives
- axis.m: Fix issues with `equal` argument
- ordeig.m: Do not fail on 1x1 matrices

GUI

- fix editors search and replace in selection
- undo a complete replace all action in the editor
- fix missing unlock of mutex when gui editor is not present
- prevent unnamed editor tab from being closed by `rmdir`
- prevent editor from closing files that are not affected by `rmdir`
- fix creating keyword files for editor autocompletion
- fix dock widget position when being dragged out of the main window

Build system / Tests

- configure: prevent overlinking when SUNDIALS is disabled
- use QtCore and Qt5Gui modules instead of Qt5OpenGL
- make building with Qt4 QGLWidget work again
- build: adapt mk-qthelp.pl to changes in Texinfo 6.7.
- BIST should not rely on the current directory to be writable.
- bp-table.cc: Fix test.
- maint: Make old style class tests Matlab compatible.
- Add BIST tests for `unlink`

Documentation

- fix many spelling errors
- help: improve documentation for the `startup.m` user script.
- avoid conflict with @seealso macro in Texinfo 6.6
- mk-doc-cache.pk: Also translate `@seealso` here.
- __makeinfo__.m: Also translate `@seealso` here
- polar.m: Document that input is expected to be in radians
- gallery.m: Fix typo in docstring for poisson
- Add 1024x1024 Octave logo icon
- add `.editorconfig` for default file encoding and indentation.
- octave.doap: Copy localized (short) description over from appdata
- org.octave.Octave.appdata.xml: Add German and French description
- languages/*.ts: updated language files
- quiver3.m: Fix texinfo typo in docstring from cset f7b10bd40045.
- doc: fix `.` Operator Index entry to build with Texinfo 6.7.
- doc: improve example of using global variables from oct-files.
- doc: Create en-dashes and em-dashes correctly in documentation.
- doc: expand `page_output_immediately` doc string, mention `page_screen_output`.
- doc: Clarify documentation of `history_file`
- doc: Improve documentation for `get_help_text`, `get_help_text_from_file`.
- doc: Add documentation for `GNUTERM` variable used with gnuplot
- doc: Improve `contour` docstring example
- doc: Add example to show limitations of the given BLAS integer size.
- doc: Improve documentation of sparse functions.
- doc: Improve spelling of `bicgstab`
- doc: Remove `Map` functions `keys`, `values`, `remove` from unimplemented list
- doc: Add function index entry for alias `inverse`
- add content rating declaration to AppStream metadata
- doc: Remove stray semicolons from `pie`, `pie3` calling forms.
- doc: Redo documentation for `rats` function.
- doc: Specify `position` property for text objects is a three-element vector
- doc: state that Octave can only load HDF5 files created by itself
- doc: Fix names of options in `issorted`
- doc: Small fixes to `mat2cell` and `polyeig` docstrings
- doc: Improve example code for using `-pdflatexstandalone`
- doc: Refer to "root object" rather than "root figure object".
- doc: Place cross-reference from list of graphics object properties back to object
- doc: document the newline character in warning messages
- doc: pkg versions can be more general than "x.y.z"


To generate a diff of this commit:
cvs rdiff -u -r1.201 -r1.202 pkgsrc/math/octave/Makefile
cvs rdiff -u -r1.33 -r1.34 pkgsrc/math/octave/PLIST
cvs rdiff -u -r1.19 -r1.20 pkgsrc/math/octave/buildlink3.mk
cvs rdiff -u -r1.57 -r1.58 pkgsrc/math/octave/distinfo
cvs rdiff -u -r1.8 -r1.9 pkgsrc/math/octave/octave.mk
cvs rdiff -u -r1.1 -r1.2 \
    pkgsrc/math/octave/patches/patch-libinterp_corefcn_input.cc
cvs rdiff -u -r1.2 -r1.3 pkgsrc/math/octave/patches/patch-m4_acinclude.m4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: pkgsrc/math/octave/Makefile
diff -u pkgsrc/math/octave/Makefile:1.201 pkgsrc/math/octave/Makefile:1.202
--- pkgsrc/math/octave/Makefile:1.201   Tue Mar 10 22:10:30 2020
+++ pkgsrc/math/octave/Makefile Sun Apr 12 21:19:32 2020
@@ -1,12 +1,12 @@
-# $NetBSD: Makefile,v 1.201 2020/03/10 22:10:30 wiz Exp $
+# $NetBSD: Makefile,v 1.202 2020/04/12 21:19:32 adam Exp $
 
-DISTNAME=      octave-5.1.0
-PKGREVISION=   13
+DISTNAME=      octave-5.2.0
 CATEGORIES=    math
 MASTER_SITES=  ${MASTER_SITE_GNU:=octave/}
+EXTRACT_SUFX=  .tar.xz
 
 MAINTAINER=    adam%NetBSD.org@localhost
-HOMEPAGE=      http://www.octave.org/
+HOMEPAGE=      https://www.gnu.org/software/octave/
 COMMENT=       High-level language, intended for numerical computations
 LICENSE=       gnu-gpl-v3
 
@@ -20,23 +20,20 @@ LICENSE=    gnu-gpl-v3
 
 DEPENDS+=      gnuplot>=3.7:../../graphics/gnuplot
 
+USE_LANGUAGES=         c c++ fortran77
 USE_LIBTOOL=           yes
 USE_TOOLS+=            autoconf gsed gmake:run perl pkg-config bison bsdtar:run
 USE_TOOLS+=            makeinfo:test
 GNU_CONFIGURE=         yes
 
-USE_LANGUAGES=         c c++ fortran77
-
 # needed for loading of shared objects such as those in the
 # octave-forge package or user written ones compiled with mkoctfile
 CONFIGURE_ARGS+=       --enable-static
 CONFIGURE_ARGS+=       --enable-shared
-
 #CONFIGURE_ARGS+=      --without-opengl
 #CONFIGURE_ARGS+=      --with-framework-opengl=no
 CONFIGURE_ARGS+=       --disable-java
-# use this to bypass qt5 portability issues:
-#CONFIGURE_ARGS+=      CPPFLAGS=-DQT_DISABLE_DEPRECATED_BEFORE=0
+TEST_TARGET=           check
 
 # Provide a full path gfortran in MKOCTFILE for octave-forge
 CONFIGURE_ENV+=                MKOCTFILE_F77=${FCPATH}
@@ -55,18 +52,17 @@ CONFIGURE_ENV+=             INSTALL_LIB=${INSTALL_L
 
 .include "options.mk"
 
-INFO_FILES=            yes
-OCTAVE_DOC=            doc/interpreter/octave.pdf doc/liboctave/liboctave.pdf \
+INFO_FILES=    yes
+OCTAVE_DOC=    doc/interpreter/octave.pdf doc/liboctave/liboctave.pdf \
                doc/refcard/refcard-a4.pdf doc/refcard/refcard-legal.pdf \
                doc/refcard/refcard-letter.pdf
+
 INSTALLATION_DIRS+=    share/octave/${PKGVERSION_NOREV}/doc
 
 PRINT_PLIST_AWK+=      { gsub(/${MACHINE_GNU_PLATFORM}/, "$${MACHINE_GNU_PLATFORM}"); }
 CHECK_WRKREF_SKIP+=    lib/octave/${PKGVERSION_NOREV}/liboctinterp*.${SHLIB_TYPE}* \
                        lib/octave/${PKGVERSION_NOREV}/liboctinterp.a
 
-TEST_TARGET=   check
-
 SUBST_CLASSES+=                        fix-make
 SUBST_STAGE.fix-make=          pre-configure
 SUBST_MESSAGE.fix-make=                Fixing path to gmake.
@@ -88,9 +84,9 @@ SUBST_SED.qt5-pkg-config+=    -e 's,QtOpenG
 CFLAGS+=       -fPIC
 .endif
 
-PREPEND_PATH+=                 ${QTDIR}/bin
+PREPEND_PATH+=         ${QTDIR}/bin
 
-CHECK_WRKREF_SKIP+=            lib/octave/5.1.0/liboctinterp.so*
+CHECK_WRKREF_SKIP+=    lib/octave/${PKGVERSION_NOREV}/liboctinterp.so*
 
 pre-configure:
         cd ${WRKSRC} && autoconf
@@ -102,6 +98,7 @@ post-install:
        ${RM} -f ${DESTDIR}/${PREFIX}/lib/charset.alias
 
 .include "../../audio/libsndfile/buildlink3.mk"
+.include "../../devel/gperf/buildlink3.mk"
 .include "../../devel/ncurses/buildlink3.mk"
 .include "../../devel/pcre/buildlink3.mk"
 .include "../../devel/readline/buildlink3.mk"
@@ -112,15 +109,12 @@ post-install:
 .include "../../math/fftw/buildlink3.mk"
 .include "../../math/fftwf/buildlink3.mk"
 .include "../../math/lapack/buildlink3.mk"
+.include "../../sysutils/desktop-file-utils/desktopdb.mk"
 .include "../../www/curl/buildlink3.mk"
+.include "../../x11/fltk13/buildlink3.mk"
 .if ${OPSYS} != "Darwin"
 .include "../../x11/libX11/buildlink3.mk"
 .endif
 .include "../../x11/qt5-qtbase/buildlink3.mk"
 .include "../../x11/qt5-qttools/buildlink3.mk"
-BUILDLINK_DEPMETHOD.gperf?=build
-.include "../../devel/gperf/buildlink3.mk"
-.include "../../x11/fltk13/buildlink3.mk"
-
-.include "../../sysutils/desktop-file-utils/desktopdb.mk"
 .include "../../mk/bsd.pkg.mk"

Index: pkgsrc/math/octave/PLIST
diff -u pkgsrc/math/octave/PLIST:1.33 pkgsrc/math/octave/PLIST:1.34
--- pkgsrc/math/octave/PLIST:1.33       Tue Mar  5 11:11:12 2019
+++ pkgsrc/math/octave/PLIST    Sun Apr 12 21:19:32 2020
@@ -1,8 +1,8 @@
-@comment $NetBSD: PLIST,v 1.33 2019/03/05 11:11:12 ryoon Exp $
+@comment $NetBSD: PLIST,v 1.34 2020/04/12 21:19:32 adam Exp $
+bin/${PKGNAME}
 bin/mkoctfile
 bin/mkoctfile-${PKGVERSION}
 bin/octave
-bin/${PKGNAME}
 bin/octave-cli
 bin/octave-cli-${PKGVERSION}
 bin/octave-config
@@ -796,13 +796,20 @@ lib/octave/${PKGVERSION}/oct/${MACHINE_G
 lib/octave/${PKGVERSION}/oct/${MACHINE_GNU_PLATFORM}/symbfact.oct
 lib/octave/${PKGVERSION}/oct/${MACHINE_GNU_PLATFORM}/symrcm.oct
 lib/octave/${PKGVERSION}/qr.a
+@pkgdir lib/octave/${PKGVERSION}/site/oct/${MACHINE_GNU_PLATFORM}
 lib/octave/${PKGVERSION}/symbfact.a
 lib/octave/${PKGVERSION}/symrcm.a
+@pkgdir lib/octave/site/oct/${MACHINE_GNU_PLATFORM}
+@pkgdir lib/octave/site/oct/api-v53/${MACHINE_GNU_PLATFORM}
 lib/pkgconfig/octave.pc
 lib/pkgconfig/octinterp.pc
 libexec/octave/${PKGVERSION}/exec/${MACHINE_GNU_PLATFORM}/octave-gui
 libexec/octave/${PKGVERSION}/exec/${MACHINE_GNU_PLATFORM}/octave-svgconvert
+@pkgdir libexec/octave/${PKGVERSION}/site/exec/${MACHINE_GNU_PLATFORM}
+@pkgdir libexec/octave/api-v53/site/exec/${MACHINE_GNU_PLATFORM}
+@pkgdir libexec/octave/site/exec/${MACHINE_GNU_PLATFORM}
 share/applications/org.octave.Octave.desktop
+share/icons/hicolor/1024x1024/apps/octave.png
 share/icons/hicolor/128x128/apps/octave.png
 share/icons/hicolor/16x16/apps/octave.png
 share/icons/hicolor/22x22/apps/octave.png
@@ -1002,6 +1009,7 @@ share/octave/${PKGVERSION}/etc/tests/fix
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Sneetch/display.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/Snork.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/cack.m
+share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/ctranspose.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/display.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/double.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/end.m
@@ -1033,6 +1041,7 @@ share/octave/${PKGVERSION}/etc/tests/fix
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/subsref.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/tattack.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/times.m
+share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/transpose.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/uminus.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/uplus.m
 share/octave/${PKGVERSION}/etc/tests/fixed/classes/@Snork/vertcat.m
@@ -1256,6 +1265,7 @@ share/octave/${PKGVERSION}/etc/tests/lib
 share/octave/${PKGVERSION}/etc/tests/libinterp/octave-value/ov-usr-fcn.cc-tst
 share/octave/${PKGVERSION}/etc/tests/libinterp/octave-value/ov.cc-tst
 share/octave/${PKGVERSION}/etc/tests/libinterp/octave.cc-tst
+share/octave/${PKGVERSION}/etc/tests/libinterp/parse-tree/bp-table.cc-tst
 share/octave/${PKGVERSION}/etc/tests/libinterp/parse-tree/lex.ll-tst
 share/octave/${PKGVERSION}/etc/tests/libinterp/parse-tree/oct-parse.yy-tst
 share/octave/${PKGVERSION}/etc/tests/libinterp/parse-tree/pt-assign.cc-tst
@@ -2259,12 +2269,6 @@ share/octave/${PKGVERSION}/m/time/etime.
 share/octave/${PKGVERSION}/m/time/is_leap_year.m
 share/octave/${PKGVERSION}/m/time/now.m
 share/octave/${PKGVERSION}/m/time/weekday.m
-share/octave/site/m/startup/octaverc
-@pkgdir share/octave/site/api-v53/m
 @pkgdir share/octave/${PKGVERSION}/site/m
-@pkgdir libexec/octave/site/exec/${MACHINE_GNU_PLATFORM}
-@pkgdir libexec/octave/api-v53/site/exec/${MACHINE_GNU_PLATFORM}
-@pkgdir libexec/octave/${PKGVERSION}/site/exec/${MACHINE_GNU_PLATFORM}
-@pkgdir lib/octave/site/oct/${MACHINE_GNU_PLATFORM}
-@pkgdir lib/octave/site/oct/api-v53/${MACHINE_GNU_PLATFORM}
-@pkgdir lib/octave/${PKGVERSION}/site/oct/${MACHINE_GNU_PLATFORM}
+@pkgdir share/octave/site/api-v53/m
+share/octave/site/m/startup/octaverc

Index: pkgsrc/math/octave/buildlink3.mk
diff -u pkgsrc/math/octave/buildlink3.mk:1.19 pkgsrc/math/octave/buildlink3.mk:1.20
--- pkgsrc/math/octave/buildlink3.mk:1.19       Sat Dec 31 09:26:31 2016
+++ pkgsrc/math/octave/buildlink3.mk    Sun Apr 12 21:19:32 2020
@@ -1,4 +1,4 @@
-# $NetBSD: buildlink3.mk,v 1.19 2016/12/31 09:26:31 wiz Exp $
+# $NetBSD: buildlink3.mk,v 1.20 2020/04/12 21:19:32 adam Exp $
 
 BUILDLINK_TREE+=       octave
 
@@ -14,7 +14,7 @@ BUILDLINK_PKGSRCDIR.octave?=  ../../math/
 pkgbase := octave
 .include "../../mk/pkg-build-options.mk"
 
-.if !empty(PKG_BUILD_OPTIONS.octave:Mhdf5)
+.if ${PKG_BUILD_OPTIONS.octave:Mhdf5}
 .  include "../../devel/hdf5/buildlink3.mk"
 .endif
 

Index: pkgsrc/math/octave/distinfo
diff -u pkgsrc/math/octave/distinfo:1.57 pkgsrc/math/octave/distinfo:1.58
--- pkgsrc/math/octave/distinfo:1.57    Tue Dec 24 01:58:48 2019
+++ pkgsrc/math/octave/distinfo Sun Apr 12 21:19:32 2020
@@ -1,19 +1,19 @@
-$NetBSD: distinfo,v 1.57 2019/12/24 01:58:48 dbj Exp $
+$NetBSD: distinfo,v 1.58 2020/04/12 21:19:32 adam Exp $
 
-SHA1 (octave-5.1.0.tar.gz) = 75a5ec450473e4c39290fdab9feade4a5739e465
-RMD160 (octave-5.1.0.tar.gz) = b8b4469d70f1b67be688e12ff551e6b614c70213
-SHA512 (octave-5.1.0.tar.gz) = a842fb50c13f25e9d425fe9a2c71d9433d7e125747d2175efe0c9b2a780c799d9ce1ee085b5a13fbfedb7990b0ba5d11079d880ddb3bdb66782efc321390eebb
-Size (octave-5.1.0.tar.gz) = 32034788 bytes
+SHA1 (octave-5.2.0.tar.xz) = ae719ca7043f8662f932a41bb8d9c7ea32ff9cc9
+RMD160 (octave-5.2.0.tar.xz) = 31fc99a3bb9731be5ea4ecfa5b9913b43768e429
+SHA512 (octave-5.2.0.tar.xz) = 1d88e9f7aec4306cad676ba1ccfcd2ac561aa12c3da0769d3a375deff742c4924c8f8660a949db23ad4011495907bfbb856ce05d2f95b3450d8b2a4da4ef2361
+Size (octave-5.2.0.tar.xz) = 25439716 bytes
 SHA1 (patch-configure.ac) = df35493bc99f8b133865d96f079f603a33ef5cc4
 SHA1 (patch-doc_interpreter_module.mk) = 66389cceddbe71fca0c8197275a839170d64ad5b
 SHA1 (patch-fseeko-fpos_t.c) = b38e7a38be2e0b323cd7f168f1d22d3df998691c
 SHA1 (patch-libgnu_stdio.in.h) = 112a424655d46c75fb68531fe7a84d9a0e97a984
-SHA1 (patch-libinterp_corefcn_input.cc) = 1dc78f00ffbb41f493ebc0889cc0a37d598507c5
+SHA1 (patch-libinterp_corefcn_input.cc) = 865fe4e50f2658d2d221cf8d30d778fa9a632f5f
 SHA1 (patch-libinterp_dldfcn_config-module.awk) = 54b64357b1ef80c5e55eb5eccf742d2267eb277d
 SHA1 (patch-libinterp_dldfcn_module.mk) = 2362d824497a8892078437c24757ae1e40e2e556
-SHA1 (patch-liboctave_util_quit.cc) = 8e0209068be7d48ccebbce0e08a29072c07b0d22
+SHA1 (patch-liboctave_util_quit.cc) = 47d7c20c34e7474cd302bc28aca438ee3c3b0f57
 SHA1 (patch-liboctave_wrappers_iconv-wrappers.h) = 9995e784844ae2c2d7a77f975cd8b8954ab8a773
-SHA1 (patch-m4_acinclude.m4) = 16dfa3a47403b0c6bc5935fdb5f1162a393b3f25
+SHA1 (patch-m4_acinclude.m4) = 2c5b2fc9bfe3b9b1e1feec805338ed92ed3953e1
 SHA1 (patch-scripts_miscellaneous_unpack.m) = 82c9ca170762e223c8e5a6f88a7dd9fe2a2a33d0
 SHA1 (patch-scripts_pkg_private_configure__make.m) = 7d4b620f889faa66c4c9c581ef8a7e7692b68c94
 SHA1 (patch-scripts_plot_util_____gnuplot__drawnow____.m) = 449b178aefd78c5c1b03ffd960f2e8be3874efc2

Index: pkgsrc/math/octave/octave.mk
diff -u pkgsrc/math/octave/octave.mk:1.8 pkgsrc/math/octave/octave.mk:1.9
--- pkgsrc/math/octave/octave.mk:1.8    Sun Apr 12 20:46:20 2009
+++ pkgsrc/math/octave/octave.mk        Sun Apr 12 21:19:32 2020
@@ -1,8 +1,8 @@
-# $NetBSD: octave.mk,v 1.8 2009/04/12 20:46:20 adam Exp $
+# $NetBSD: octave.mk,v 1.9 2020/04/12 21:19:32 adam Exp $
 
 .include "../../mk/bsd.prefs.mk"
 
-OCTAVE_CONFIG= ${LOCALBASE}/bin/octave-config
+OCTAVE_CONFIG= ${PREFIX}/bin/octave-config
 
 # OCTAVE_VARS is a list of variables to define in the make environment.
 # This may be overridden in an octave add-on package Makefile.
@@ -24,6 +24,6 @@ OCT_${var}!=  ${OCTAVE_CONFIG} -p ${var}
 .if defined(REPLACE_OCTAVE)
 REPLACE_INTERPRETER+=  octave
 REPLACE.octave.old=    .*octave
-REPLACE.octave.new=    ${LOCALBASE}/bin/octave
+REPLACE.octave.new=    ${PREFIX}/bin/octave
 REPLACE_FILES.octave=  ${REPLACE_OCTAVE}
 .endif # defined(REPLACE_OCTAVE)

Index: pkgsrc/math/octave/patches/patch-m4_acinclude.m4
diff -u pkgsrc/math/octave/patches/patch-m4_acinclude.m4:1.2 pkgsrc/math/octave/patches/patch-m4_acinclude.m4:1.3
--- pkgsrc/math/octave/patches/patch-m4_acinclude.m4:1.2        Wed Dec 26 10:45:46 2018
+++ pkgsrc/math/octave/patches/patch-m4_acinclude.m4    Sun Apr 12 21:19:32 2020
@@ -1,4 +1,4 @@
-$NetBSD: patch-m4_acinclude.m4,v 1.2 2018/12/26 10:45:46 adam Exp $
+$NetBSD: patch-m4_acinclude.m4,v 1.3 2020/04/12 21:19:32 adam Exp $
 
 we pass and assume a given MACHINE_GNU_PLATFORM, but this package did not
 use this value due to an error.
@@ -8,7 +8,9 @@ https://mail-index.netbsd.org/pkgsrc-use
 
 Do not look for qcollectiongenerator; it is now part of qhelpgenerator.
 
---- m4/acinclude.m4.orig       2018-08-09 18:20:32.000000000 +0000
+On Darwin, do not produce a mach-o bundle.
+
+--- m4/acinclude.m4.orig       2019-02-23 17:33:37.000000000 +0000
 +++ m4/acinclude.m4
 @@ -31,7 +31,7 @@ AC_DEFUN([OCTAVE_CANONICAL_HOST], [
      host=unknown-unknown-unknown
@@ -19,7 +21,7 @@ Do not look for qcollectiongenerator; it
    AC_SUBST(canonical_host_type)
    if test -z "$host_cpu"; then
      host_cpu=unknown
-@@ -2011,11 +2011,10 @@ AC_DEFUN([OCTAVE_CHECK_QT_VERSION], [AC_
+@@ -2045,11 +2045,10 @@ AC_DEFUN([OCTAVE_CHECK_QT_VERSION], [AC_
      OCTAVE_CHECK_QT_TOOL([uic])
      OCTAVE_CHECK_QT_TOOL([rcc])
      OCTAVE_CHECK_QT_TOOL([lrelease])
@@ -32,3 +34,14 @@ Do not look for qcollectiongenerator; it
        build_qt_gui=no
        MOC_QTVER=
        UIC_QTVER=
+@@ -2979,10 +2978,8 @@ AC_DEFUN_ONCE([OCTAVE_DEFINE_MKOCTFILE_D
+       SH_LDFLAGS="-shared -Wl,-expect_unresolved -Wl,'*'"
+     ;;
+     *-*-darwin*)
+-      DL_LDFLAGS="-bundle -bundle_loader ${ac_top_build_prefix}libinterp/octave ${LDFLAGS}"
+       dnl Contains variables that are defined and undefined at this point, so use
+       dnl appropriate quoting to defer expansion of ${bindir} and ${version}.
+-      MKOCTFILE_DL_LDFLAGS='-bundle -bundle_loader ${bindir}/octave-${version}'"${EXEEXT}"
+       SH_LDFLAGS="-dynamiclib -single_module ${LDFLAGS}"
+       case $canonical_host_type in
+         powerpc-*)



Home | Main Index | Thread Index | Old Index
Index: pkgsrc/math/octave/patches/patch-libinterp_corefcn_input.cc
diff -u pkgsrc/math/octave/patches/patch-libinterp_corefcn_input.cc:1.1 pkgsrc/math/octave/patches/patch-libinterp_corefcn_input.cc:1.2
--- pkgsrc/math/octave/patches/patch-libinterp_corefcn_input.cc:1.1     Tue Mar  5 11:11:12 2019
+++ pkgsrc/math/octave/patches/patch-libinterp_corefcn_input.cc Sun Apr 12 21:19:32 2020
@@ -1,15 +1,15 @@
-$NetBSD: patch-libinterp_corefcn_input.cc,v 1.1 2019/03/05 11:11:12 ryoon Exp $
+$NetBSD: patch-libinterp_corefcn_input.cc,v 1.2 2020/04/12 21:19:32 adam Exp $
 
-* Do not conflict between header and body
+Do not conflict between header and body
 
---- libinterp/corefcn/input.cc.orig    2019-02-23 17:33:37.000000000 +0000
+--- libinterp/corefcn/input.cc.orig    2020-01-28 01:57:35.000000000 +0000
 +++ libinterp/corefcn/input.cc
 @@ -521,7 +521,7 @@ namespace octave
                ? octave_locale_charset_wrapper () : m_mfile_encoding;
  
              // Check for valid codepage.
 -            void *codec
 +            iconv_t codec
-               = octave_iconv_open_wrapper (codepage.c_str (), "utf-8");
+               = octave_iconv_open_wrapper (encoding.c_str (), "utf-8");
  
-             if (errno == EINVAL)
+             if (codec == reinterpret_cast<void *> (-1))
@@ -1,15 +1,15 @@
                ? octave_locale_charset_wrapper () : m_mfile_encoding;
  
-             // Check for valid codepage.
+             // Check for valid encoding name.
 -            void *codec
 +            iconv_t codec
